/*
 * This file is part of Nuts Framework.
 * Copyright (C) 2009 http://nuts.sourceforge.jp
 *
 * Nuts Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License any later version.
 *
 * Nuts Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Nuts Framework. If not, see <http://www.gnu.org/licenses/>.
 */
package nuts.ext.struts2.util;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.jsp.PageContext;

import nuts.ext.xwork2.util.ContextUtils;

import org.apache.struts2.ServletActionContext;
import org.apache.struts2.StrutsStatics;
import org.apache.struts2.dispatcher.Dispatcher;
import org.apache.struts2.dispatcher.mapper.ActionMapping;
import org.apache.struts2.interceptor.PrincipalProxy;
import org.apache.struts2.servlet.interceptor.ServletPrincipalProxy;

import com.opensymphony.xwork2.ActionContext;
import com.opensymphony.xwork2.ActionInvocation;
import com.opensymphony.xwork2.inject.Container;
import com.opensymphony.xwork2.util.ValueStack;

/**
 * StrutsContextUtils
 */
public class StrutsContextUtils extends ContextUtils implements StrutsStatics {

	/**
	 * @return Container
	 */
	public static Container getContainer() {
		return Dispatcher.getInstance().getContainer();
	}

	/**
	 * Gets the current action context
	 *
	 * @param req The request
	 * @return The current action context
	 * @see ServletActionContext#getActionContext(HttpServletRequest)
	 */
	public static ActionContext getActionContext(HttpServletRequest req) {
		return ServletActionContext.getActionContext(req);
	}

	/**
	 * Gets the current value stack for this request
	 *
	 * @param req The request
	 * @return The value stack
	 * @see ServletActionContext#getValueStack(HttpServletRequest)
	 */
	public static ValueStack getValueStack(HttpServletRequest req) {
		return ServletActionContext.getValueStack(req);
	}

	/**
	 * Gets the action mapping for this context
	 *
	 * @return The action mapping
	 * @see ServletActionContext#getActionMapping()
	 */
	public static ActionMapping getActionMapping() {
		return ServletActionContext.getActionMapping();
	}

	/**
	 * Returns the HTTP page context.
	 *
	 * @return the HTTP page context.
	 * @see ServletActionContext#getPageContext()
	 */
	public static PageContext getPageContext() {
		return ServletActionContext.getPageContext();
	}

	/**
	 * Gets the HTTP servlet request object.
	 *
	 * @return the HTTP servlet request object.
	 * @see ServletActionContext#getRequest()
	 */
	public static HttpServletRequest getServletRequest() {
		return ServletActionContext.getRequest();
	}

	/**
	 * Gets the HTTP servlet request object.
	 *
	 * @param invocation action invocation
	 * @return the HTTP servlet request object.
	 */
	public static HttpServletRequest getServletRequest(ActionInvocation invocation) {
		return (HttpServletRequest)invocation.getInvocationContext().get(HTTP_REQUEST);
	}

	/**
	 * Gets the HTTP servlet response object.
	 *
	 * @return the HTTP servlet response object.
	 * @see ServletActionContext#getResponse()
	 */
	public static HttpServletResponse getServletResponse() {
		return ServletActionContext.getResponse();
	}

	/**
	 * Gets the HTTP servlet responset object.
	 *
	 * @param invocation action invocation
	 * @return the HTTP servlet response object.
	 */
	public static HttpServletResponse getServletResponse(ActionInvocation invocation) {
		return (HttpServletResponse)invocation.getInvocationContext().get(HTTP_RESPONSE);
	}

	/**
	 * Gets the servlet context.
	 *
	 * @return the servlet context.
	 * @see ServletActionContext#getServletContext()
	 */
	public static ServletContext getServletContext() {
		return ServletActionContext.getServletContext();
	}

	/**
	 * Gets the PrincipalProxy object.
	 *
	 * @return the PrincipalProxy object.
	 */
	public static PrincipalProxy getPrincipalProxy() {
		HttpServletRequest request = getServletRequest();
		if (request != null) {
			// We are in servtlet environment, so principal information resides in
			// HttpServletRequest
			return new ServletPrincipalProxy(request);
		}
		return null;
	}
}
